# spaceprime


[![image](https://img.shields.io/pypi/v/spaceprime.svg)](https://pypi.python.org/pypi/spaceprime)
[![image](https://img.shields.io/conda/vn/conda-forge/spaceprime.svg)](https://anaconda.org/conda-forge/spaceprime)


**A python package to facilitate spatially explicit coalescent modeling in msprime**


-   Free software: MIT License
-   Documentation: https://connor-french.github.io/spaceprime
    

## Features

-   TODO

